import { Component, OnInit, AfterViewInit, ViewChild } from '@angular/core';
import { MatTableDataSource, MatSort } from '@angular/material';
import { AfterContentInit } from '@angular/core/src/metadata/lifecycle_hooks';
import { Router } from '@angular/router';
import { Sensor } from '../../model';

import { Store, select } from '@ngrx/store';

import * as SensorStore from '../../store';

import { RPCError } from 'packages/core/rpc/error';
import * as ReadAllByDomainStore from '../../store/readallbydomain';
import { ReadAllByMemberSelector } from '../../store';

import * as TargetStore from 'packages/target/store/target';
import { ReadAllByDomainSelector as TargetReadAllByDomainSelector  } from 'packages/target/store';

import { Domain } from '../../../domain/model';
import { Target } from '../../../target/model';
import { ITreeOptions } from 'angular-tree-component';

@Component({
  selector: 'of-sensor-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.scss']
})
export class ListComponent implements OnInit, AfterContentInit {

  sensorList$ = this.store.pipe(select(ReadAllByMemberSelector.select('sensorList')));
  targetList$ = this.store.pipe(select(ReadAllByMemberSelector.select('sensorList')));

  displayedColumns = ['crawler', 'type', 'name', 'sensors'];
  dataSource: MatTableDataSource<Sensor>;
  @ViewChild(MatSort) sort: MatSort;

  displayedColumnsTarget = ['createDate', 'displayName', 'description'];
  dataSourceTarget: MatTableDataSource<Target>;
  @ViewChild(MatSort) sortTarget: MatSort;


  nodes2 = [
    {
      title: 'root1',
      className: 'root1Class'
    },
    {
      title: 'root2',
      className: 'root2Class',
      children: [
        { title: 'child1', className: 'child1Class' },
        { title: 'child2', className: 'child1Class' },
        { title: 'child3', className: 'child1Class' }
      ]
    }
  ];

  /**
   * Set the sort after the view init since this component will
   * be able to query its view for the initialized sort.
   */

  clickCheck(node) {

    // console.log(node);

    console.log(node.isActive);

    const active: boolean = !node.isActive;

    if (node.visibleChildren.length > 0) {
      node.visibleChildren.map(cn => {
        (function (cc) {
          cc.setIsActive(active);
        }(cn));
      });
    }

    node.toggleActivated(true);

  }

  ngAfterContentInit() {
    // temporary data
    // const data: Sensor[] = new Array();
    // for (let i = 0; i < 3; i++) {
    //   const t: Sensor = {
    //     id: i,
    //     target: {
    //       id: 1,
    //       displayName: '192.168.1.1',
    //     },
    //     crawler: {
    //       id: 1,
    //       name: 'WMI'
    //     },
    //   };
    //   data.push(t);
    // }

    this.store.select(ReadAllByMemberSelector.select('domain')).subscribe(
      (domain: Domain) => {
        this.store.dispatch(new ReadAllByDomainStore.ReadAllByDomain(domain));
      },
      (error) => {
        console.log(error);
      }
    );

    // this.store.select(TargetReadAllByDomainSelector.select('target')).subscribe(
    //   (domain: Domain) => {
    //     this.store.dispatch(new TargetStore.ReadAllByDomain(domain));
    //   },
    // );

    // const domain: Domain = {
    //   id: 1
    // };

    // this.store.dispatch(new ReadAllByDomainStore.ReadAllByDomain(domain));

    this.sensorList$.subscribe(
      (probes: Sensor[]) => {
        console.log(probes);
        this.dataSource = new MatTableDataSource(probes);
        this.dataSource.sort = this.sort;
      },
      (error: RPCError) => {
        // console.log(error.response.message);
      }
    );

    this.targetList$.subscribe(
      (targets: Target[]) => {

      },
      (error: RPCError) => {
        console.log(error.message);
      }
    );


    // this.dataSource = new MatTableDataSource(data);
    // this.dataSource.sort = this.sort;
  }

  constructor(private router: Router,
    private store: Store<ReadAllByDomainStore.State>) { }

  ngOnInit() {
  }

  handleRowClick(obj: Sensor) {
    this.router.navigate(['target', obj.id]);
  }
}
